=========
sonic
=========


.. image:: https://img.shields.io/pypi/v/sonic.svg
        :target: https://pypi.python.org/pypi/sonic

.. image:: https://img.shields.io/travis/symonk/sonic.svg
        :target: https://travis-ci.com/symonk/sonic

.. image:: https://readthedocs.org/projects/sonic/badge/?version=latest
        :target: https://sonic.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/symonk/sonic/shield.svg
     :target: https://pyup.io/repos/github/symonk/sonic/
     :alt: Updates

.. image:: https://results.pre-commit.ci/badge/github/symonk/sonic/master.svg
   :target: https://results.pre-commit.ci/latest/github/symonk/sonic/master
   :alt: pre-commit.ci status



Port scanning made easy with python


* Free software: MIT license
* Documentation: https://sonic.readthedocs.io.

--------
Disclaimer
--------
Do **not** use this against any environment in which you do not have complete, explicit permission to conduct such scanning.

Features
--------

* Simple port scanning
* Powerful customisations
* Result dispatching
* Hook based extendibility
